@@ -13,7 +13,8 @@
 #' columns on the left. 'between' is SQL like, i.e. inclusive. 'top_n' highlights the n highest values columns, 'bottom_n'
 #' hightlights the lowest n values. 'max' and 'min' are equivalent of top_1 and bottom_1. 'contains' uses \code{grepl()} to see
 #' if values of a column contain a pattern specified in \code{value}. 'color-rank' applies
-#' one of the \code{color_rank_theme}s.
+#' one of the \code{color_rank_theme}. 'logical' allows the user to provide a list of logical vectors to identify where to apply the css.
+#' This option is convenient when the condition is complex, for example if it relies on other columns in the table.
 #'
 #' @param n the number of rows to highlight in 'top_n' and 'bottom_n'. If no value for n is provided, 1 is assumed
 #' with a warning.
@@ -44,8 +45,15 @@
 #' in conjunction. If TRUE, the condition will be evaluated on all values of all \code{columns}. If FALSE,
 #' the condition will be evaluated per column.
 #'
+#' @param logical_conditions A list of logical vectors indicating where the condition holds in each column
+#' provided in the \code{columns} parameter. Should be provided when \code{conditional} is 'logical'.
+#' The length of the list should have the same length as \code{columns}, and the length of each vector
+#' in the list should equal the number of rows in the table. If one logical vector is given it wil be
+#' applied on all given columns.
+#'
 #' @param levels Deprecated. Please change the factor levels in the input data of \code{tableHTML}.
 #'
+#'
 #' @inheritParams add_css_column
 #' @inheritParams base::order
 #'
@@ -96,14 +104,14 @@
 #'                              columns = 11)
 #'
 #' tableHTML(mtcars) %>%
-#'  add_theme('scientific') %>%
-#'  add_css_conditional_column(conditional = "color_rank",
-#'                             color_rank_theme =  "RAG",
-#'                             columns = 1) %>%
-#'  add_css_conditional_column(conditional = "color_rank",
-#'                             color_rank_theme = "Rainbow",
-#'                             columns = 5,
-#'                             decreasing = TRUE)
+#'   add_theme('scientific') %>%
+#'   add_css_conditional_column(conditional = "color_rank",
+#'                              color_rank_theme =  "RAG",
+#'                              columns = 1) %>%
+#'   add_css_conditional_column(conditional = "color_rank",
+#'                              color_rank_theme = "Rainbow",
+#'                              columns = 5,
+#'                              decreasing = TRUE)
 #'
 #' css <- make_css_color_rank_theme(list(qsec = mtcars$qsec),
 #'                                   colors = c('#E41A1C', '#377EB8', '#4DAF4A',
@@ -131,21 +139,41 @@
 #'                              columns = c(9, 10),
 #'                              same_scale = FALSE)
 #'
+#' # test the condition on a column and apply the css on another
+#' iris %>%
+#'   tableHTML(rownames = FALSE,
+#'             widths = rep(100, ncol(iris))) %>%
+#'   add_css_conditional_column(
+#'    conditional = 'logical',
+#'    columns = c('Sepal.Length', 'Petal.Length'),
+#'    css = list(c('background-color'), c('lightblue')),
+#'    logical_conditions = list(iris$Sepal.Width==3,
+#'                              iris$Petal.Width==0.3))
+#' # apply the css on a full row
+#' iris %>%
+#'   tableHTML(rownames = FALSE,
+#'             widths = rep(100, ncol(iris))) %>%
+#'   add_css_conditional_column(conditional = 'logical',
+#'                              columns = 1:ncol(iris),
+#'                              css = list(c('background-color'), c('lightblue')),
+#'                              logical_conditions = list(iris$Sepal.Width==3))
+#'
 #' @export
 
 add_css_conditional_column <- function(tableHTML,
                                        columns,
                                        conditional = c("color_rank", "==", "!=", "min", "max", "top_n", "bottom_n", ">", ">=",
-                                                       "<", "<=", "between", "contains"),
+                                                       "<", "<=", "between", "contains", "logical"),
                                        n = NULL,
                                        value = NULL,
                                        between = NULL,
                                        css = NULL,
                                        color_rank_theme = c("Custom", "RAG", "Spectral", "Rainbow",
-                                                             "White-Green", "White-Red", "White-Blue"),
+                                                            "White-Green", "White-Red", "White-Blue"),
                                        color_rank_css = NULL,
                                        decreasing = FALSE,
                                        same_scale = TRUE,
+                                       logical_conditions=NULL,
                                        levels = NULL) {
 
   #persist attributes
@@ -156,7 +184,7 @@ add_css_conditional_column <- function(tableHTML,
 
   # check if data in attributes
   if (is.null(attributes$data)) {
-   stop("tableHTML object does not have data in attributes. \nSee documentation in tableHTML()")
+    stop("tableHTML object does not have data in attributes. \nSee documentation in tableHTML()")
   }
 
   # deprecated levels
@@ -179,7 +207,6 @@ add_css_conditional_column <- function(tableHTML,
   }
 
   conditional <- match.arg(conditional)
-
   color_rank_theme <- match.arg(color_rank_theme)
 
   if (conditional %in% c("top_n", "bottom_n")) {
@@ -217,19 +244,27 @@ add_css_conditional_column <- function(tableHTML,
     }
   }
 
+  if (conditional == "logical") {
+    if (is.null(logical_conditions))
+      stop('logical_conditions should be provided for logical conditional')
+    if ((length(logical_conditions) != 1) & (length(logical_conditions) != length(columns)))
+      stop('logical_conditions should have the same length as the columns')
+    if (! all(lengths(logical_conditions) == nrow(attributes$data)))
+      stop("each vector in logical_conditions should have the same length as the number of rows")
+  }
+
   if (conditional != "color_rank") {
     if (is.null(css)) {
       stop('css needs to be provided')
     }
   }
-
   #color_rank_css structure
   if (color_rank_theme == "Custom" & conditional == "color_rank") {
     if (is.null(color_rank_css)) {
       stop("color_rank_css needs to be provided for custom conditional formatting")
     }
     if (lengths(color_rank_css) != 2) {
-     stop("color_rank_css must be a list of 2 atomic vectors")
+      stop("color_rank_css must be a list of 2 atomic vectors")
     }
     # if (! unique(unlist(lapply(1:length(color_rank_css), function(i) {
     #   lengths(color_rank_css[[i]])
@@ -283,15 +318,15 @@ add_css_conditional_column <- function(tableHTML,
   style <- switch(conditional,
                   "color_rank" = NULL,
                   {
-                  css_comp <- paste0(css[[1]], ':', css[[2]], ';')
-                  css_comp <- paste(css_comp, collapse = '')
-                  style_temp <- rep(list(rep(paste0('style="', css_comp, '"'),
-                                             attributes$nrows)),
-                                    length(all_names))
-                  names(style_temp) <- all_names
-                  style_temp
+                    css_comp <- paste0(css[[1]], ':', css[[2]], ';')
+                    css_comp <- paste(css_comp, collapse = '')
+                    style_temp <- rep(list(rep(paste0('style="', css_comp, '"'),
+                                               attributes$nrows)),
+                                      length(all_names))
+                    names(style_temp) <- all_names
+                    style_temp
                   }
-                  )
+  )
 
   color_rank_theme_colors <- switch(color_rank_theme,
                                     "RAG" = c("#86c183", "#B9D48A", "#FCEC92", "#EFAE7F","#F8696B"),
@@ -304,43 +339,53 @@ add_css_conditional_column <- function(tableHTML,
                                     NULL
   )
 
-  if (is.null(style) & !is.null(color_rank_theme_colors)) {
-
-    condition <- rep(list(rep(TRUE, attributes$nrows)), length(indices))
+  if(conditional == "logical") {
+    if(length(logical_conditions) == 1){
+      logical_conditions <- rep(logical_conditions, length(columns))
+    }
+    condition <- logical_conditions
     names(condition) <- all_names
-
   } else {
-    comparison_value <- switch(conditional,
-                               "top_n" = n,
-                               "bottom_n" = n,
-                               "between" = between,
-                               value)
 
-    column_data <- extract_column_data(tableHTML, indices)
+    if (is.null(style) & !is.null(color_rank_theme_colors)) {
 
-    condition <- conditional_test_function(column_data = column_data,
-                                           conditional = conditional,
-                                           same_scale = same_scale,
-                                           comparison_value = comparison_value)
+      condition <- rep(list(rep(TRUE, attributes$nrows)), length(indices))
+      names(condition) <- all_names
+
+    } else {
+
+      comparison_value <- switch(conditional,
+                                 "top_n" = n,
+                                 "bottom_n" = n,
+                                 "between" = between,
+                                 value)
+
+      column_data <- extract_column_data(tableHTML, indices)
+
+      condition <- conditional_test_function(column_data = column_data,
+                                             conditional = conditional,
+                                             same_scale = same_scale,
+                                             comparison_value = comparison_value)
+    }
   }
 
   if (!is.null(color_rank_theme_colors)) {
+
     column_data <- extract_column_data(tableHTML, indices)
     color_rank_css <- make_css_color_rank_theme(column_data,
-                                       color_rank_theme_colors,
-                                       decreasing = decreasing,
-                                       same_scale = same_scale)
+                                                color_rank_theme_colors,
+                                                decreasing = decreasing,
+                                                same_scale = same_scale)
   }
 
   if (is.null(style)) {
+
     style <- lapply(all_names, function(name) {
       make_style_from_css("column")(color_rank_css, name)
     })
     names(style) <- all_names
   }
 
-
-
   for (i in indices) {
 
     if (isTRUE(all.equal(i, 0))) {
